package com.ruoyi.ss.toilet.service.impl;

import java.util.List;

import com.ruoyi.ss.toilet.domain.Toilet;
import com.ruoyi.ss.toilet.domain.ToiletQuery;
import com.ruoyi.ss.toilet.domain.ToiletVO;
import com.ruoyi.ss.toilet.mapper.ToiletMapper;
import com.ruoyi.ss.toilet.service.IToiletService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 卫生间Service业务层处理
 *
 * @author qzz
 * @date 2025-01-07
 */
@Service
public class ToiletServiceImpl implements IToiletService
{
    @Autowired
    private ToiletMapper toiletMapper;

    /**
     * 查询卫生间
     *
     * @param toiletId 卫生间主键
     * @return 卫生间
     */
    @Override
    public ToiletVO selectToiletByToiletId(Long toiletId)
    {
        return toiletMapper.selectToiletByToiletId(toiletId);
    }

    /**
     * 查询卫生间列表
     *
     * @param toilet 卫生间
     * @return 卫生间
     */
    @Override
    public List<ToiletVO> selectToiletList(ToiletQuery toilet)
    {
        return toiletMapper.selectToiletList(toilet);
    }

    /**
     * 新增卫生间
     *
     * @param toilet 卫生间
     * @return 结果
     */
    @Override
    public int insertToilet(Toilet toilet)
    {
        return toiletMapper.insertToilet(toilet);
    }

    /**
     * 修改卫生间
     *
     * @param toilet 卫生间
     * @return 结果
     */
    @Override
    public int updateToilet(Toilet toilet)
    {
        return toiletMapper.updateToilet(toilet);
    }

    /**
     * 批量删除卫生间
     *
     * @param toiletIds 需要删除的卫生间主键
     * @return 结果
     */
    @Override
    public int deleteToiletByToiletIds(Long[] toiletIds)
    {
        return toiletMapper.deleteToiletByToiletIds(toiletIds);
    }

    /**
     * 删除卫生间信息
     *
     * @param toiletId 卫生间主键
     * @return 结果
     */
    @Override
    public int deleteToiletByToiletId(Long toiletId)
    {
        return toiletMapper.deleteToiletByToiletId(toiletId);
    }

    /**
     * 下架设备（根据设备id）
     * @param deviceId 设备id
     * @return String
     */
    @Override
    public int offlineDeviceByDeviceId(Long deviceId) {
        return toiletMapper.offlineDeviceByDeviceId(deviceId);
    }
}
